use easy_repl::{command, CommandStatus, Repl};
use crate::{exec, op};
use crate::repl::prepare::prepare_view;
use crate::repl::schedule_switch_root;

pub fn mgr_shell() {
    let repl_bresult = Repl::builder()
        .description("rumia-cli system view: /")
        .prompt("[ rumia-cli: / ] ")
        .add("checklist", command! {
            "print a checklist for sequences should be done for initrd",
            () => || {
                println!("Prepare Sequence:\n\
                    do-prepare\n\
                    do-fstab-mount\n\
                    swapon\n\
                    do-new-env\n\
                    do-move-mnt\n\
                ");
                Ok(CommandStatus::Done)
            }
        })
        .add("exec", command! {
            "run a command, without arguments",
            (shell: String) => |shell:String| {
                exec::shell_run_cmd(shell);
                Ok(CommandStatus::Done)
            }
        })
        .add("sh", command! {
            "run /bin/sh",
            () => || {
                exec::shell_run_cmd("/bin/sh".to_string());
                Ok(CommandStatus::Done)
            }
        })
        .add("do-prepare", command! {
            "do the sequence 'prepare'",
            () => || {
                op::seq::prepare();
                Ok(CommandStatus::Done)
            }
        })
        .add("prepare-view", command! {
            "enter the view 'prepare'",
            () => || {
                prepare_view();
                Ok(CommandStatus::Done)
            }
        })
        .add("do-fstab-mount", command! {
            "do the sequence 'fstab-mount'",
            () => || {
                op::seq::fstab_mount();
                Ok(CommandStatus::Done)
            }
        })
        .add("do-new-env", command! {
            "do the sequence 'new-env'",
            () => || {
                op::seq::new_env();
                Ok(CommandStatus::Done)
            }
        })
        .add("do-move-mnt", command! {
            "do the sequence 'move-mnt'",
            () => || {
                op::seq::move_prepare_mount();
                Ok(CommandStatus::Done)
            }
        })
        .add("swapon", command! {
            "turn on swap with config",
            () => || {
                op::once::turn_on_swap();
                Ok(CommandStatus::Done)
            }
        })
        .add("switch-root", command! {
            "switch to new root",
            () => || {
                schedule_switch_root();
                Ok(CommandStatus::Quit)
            }
        })
        .build();
    let mut repl = match repl_bresult {
        Ok(t) => t,
        Err(err) => {
            println!("[ERROR] admin Shell Init Fatal Error: {:?}", err);
            return;
        }
    };
    let repl_run_result = repl.run();
    match repl_run_result {
        Ok(_) => {}
        Err(err) => {
            println!("[ERROR] this view crash by error: {:?}", err);
            println!("back to parent view...");
        }
    };
}
